X-Git-Url: http://git.vanrenterghem.biz/git.ikiwiki.info.git/blobdiff_plain/d2e3741a6f289bd25b75683990a0548f41661a85..a8cea0f3c4f89cd82d7c7d59077d6ff73dbff93c:/IkiWiki/Plugin/websetup.pm?ds=sidebyside

diff --git a/IkiWiki/Plugin/websetup.pm b/IkiWiki/Plugin/websetup.pm
index ef9a93886..f95017c90 100644
--- a/IkiWiki/Plugin/websetup.pm
+++ b/IkiWiki/Plugin/websetup.pm
@@ -151,7 +151,10 @@ sub showfields ($$$@) {
 		my %info=%{shift @show};
 
 		my $description=$info{description};
-		if (exists $info{link} && length $info{link}) {
+		if (exists $info{htmldescription}) {
+			$description=$info{htmldescription};
+		}
+		elsif (exists $info{link} && length $info{link}) {
 			if ($info{link} =~ /^\w+:\/\//) {
 				$description="<a href=\"$info{link}\">$description</a>";
 			}
@@ -288,7 +291,7 @@ sub showform ($$) {
 		fieldsets => [
 			[main => gettext("main")], 
 		],
-		action => $config{cgiurl},
+		action => IkiWiki::cgiurl(),
 		template => {type => 'div'},
 		stylesheet => 1,
 	);
@@ -447,10 +450,10 @@ sub showform ($$) {
 			IkiWiki::saveindex();
 			IkiWiki::unlockwiki();
 
 			# Print the top part of a standard misctemplate,
 			# then show the rebuild or refresh, live.
 			my $divider="\0";
-			my $html=IkiWiki::misctemplate("setup", $divider);
+			my $html=IkiWiki::cgitemplate($cgi, "setup", $divider);
 			IkiWiki::printheader($session);
 			my ($head, $tail)=split($divider, $html, 2);
 			print $head."<pre>\n";
@@ -447,10 +450,10 @@ sub showform ($$) {
 			IkiWiki::unlockwiki();
 
-			# Print the top part of a standard misctemplate,
+			# Print the top part of a standard cgitemplate,
 			# then show the rebuild or refresh, live.
 			my $divider="\0";